Learn R Programming

glm.ddR (version 0.1.0)

summary.dglm: Summarizing The Model Made by dglm

Description

This function prints a summary of the learned model.

Usage

"summary"(object, dispersion = NULL, correlation = FALSE, symbolic.cor = FALSE, trace=FALSE, ...)

Arguments

object
a result of a call to dglm.
dispersion
the dispersion parameter for the family used. Either a single numerical value or NULL (the default), when it is inferred from object).
correlation
logical; if TRUE, the correlation matrix of the estimated parameters is returned and printed.
symbolic.cor
logical. If TRUE, print the correlations in a symbolic form (see symnum) rather than as numbers.
trace
when TRUE, intermediate steps of the progress are displayed.
...
further arguments passed to or from other methods.

Value

summary.dglm returns an object of class "summary.dglm", a list with components
call
the component from object.
family
the component from object.
deviance
the component from object.
df.residual
the component from object.
null.deviance
the component from object. It is NA for an incomplete model.
df.null
the component from object.
deviance.resid
(only when completeModel=TRUE) the deviance residuals: see residuals.dglm. It is NA for an incomplete model.
coefficients
the matrix of coefficients, standard errors, z-values and p-values. Aliased coefficients are omitted. Except coefficients, other values are NA for an incomplete model.
aliased
named logical vector showing if the original coefficients are aliased.
dispersion
either the supplied argument or the inferred/estimated dispersion if the latter is NULL.
df
a 3-vector of the rank of the model and the number of residual degrees of freedom, plus number of non-aliased coefficients.
cov.unscaled
the unscaled (dispersion = 1) estimated covariance matrix of the estimated coefficients. It is not available for an incomplete model.
cov.scaled
ditto, scaled by dispersion. It is not available for an incomplete model.
correlation
(only if correlation is true.) The estimated correlations of the estimated coefficients.
symbolic.cor
(only if correlation is true.) The value of the argument symbolic.cor.
minMax
it contains the minimum and the maximum of the deviance residuals. They are NA for an incomplete model.

Examples

Run this code
 ## Not run: 
#     require(glm.ddR)
# 
#     Y <- as.dobject(as.matrix(faithful$eruptions),
#                     c(ceiling(length(faithful$eruption)/4),1))
#     X <- as. dobject (as.matrix(faithful$waiting),
#                     c(ceiling(length(faithful$waiting)/4),1))
# 
#     myModel <- dglm(responses=Y, predictors=X)
#     summary(myModel)
#  ## End(Not run)

Run the code above in your browser using DataLab